/*$$$ 
<filter id="contrastBrightnessShader" label="$$$/Shader/Brightness/Contrast" category="adjustment" vartype="custom">
	<var varname="brightness" label="$$$/Shader/Brightness=Brightness" type="number" numFactor="100" snapToZero="true" min="-1" max="1" default="0" />
	<var varname="contrast" label="$$$/Shader/Contrast=Contrast" type="number" numFactor="100" snapToZero="true" min="-1" max="1" default="0" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;

uniform float contrast;
uniform float brightness;

varying vec2 mainTexCoord;

void main()
{
    vec4 col = texture2D(tt_uniform_maintexture, mainTexCoord.xy);
    vec4 curCol;

    vec4 dst;
    float negFactor;
    float posFactor;
	float wContrast = contrast*contrast*sign(contrast);
	float wBrightness = brightness*brightness*sign(brightness);
	
    negFactor = sign(max(-wContrast,0.0));
    posFactor = step(0.0,wContrast);

    curCol.rgb = max((col.rgb-0.5)*(1.0+wContrast) + 0.5,0.0) * negFactor;
    curCol.rgb += min(col.rgb + (col.rgb-0.5)*wContrast,1.0) * posFactor;

    negFactor = sign(max(-wBrightness,0.0));
    posFactor = step(0.0,wBrightness);

    dst.rgb = (curCol.rgb * (1.0+wBrightness)) *negFactor;
    dst.rgb += (curCol.rgb + wBrightness)*posFactor;

    gl_FragColor.rgb = min(dst.rgb,col.a);
    gl_FragColor.a = col.a;
}
